Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(128)

Unified Diff: Source/Platform/chromium/public/WebInputHandlerClient.h

Issue 13880009: Include timestamp with vsync-delineating input events (Closed) Base URL: https://chromium.googlesource.com/chromium/blink.git@master
Patch Set: Rebased. Created 7 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | Source/WebKit/chromium/src/WebCompositorInputHandlerImpl.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/Platform/chromium/public/WebInputHandlerClient.h
diff --git a/Source/Platform/chromium/public/WebInputHandlerClient.h b/Source/Platform/chromium/public/WebInputHandlerClient.h
index 15eba89b66b6d8de216121b6816bce1da177b109..decb3af218cd8a744c0485c9992992b02c6586e8 100644
--- a/Source/Platform/chromium/public/WebInputHandlerClient.h
+++ b/Source/Platform/chromium/public/WebInputHandlerClient.h
@@ -84,8 +84,10 @@ public:
// given WebPoint.
virtual bool haveTouchEventHandlersAt(WebPoint) = 0;
- // Indicate that the final input event for the current vsync interval was received.
- virtual void didReceiveLastInputEventForVSync() { }
+ // Indicate that the final input event for the current vsync interval was
+ // received. The frame time is given in the same time base as
+ // monotonicallyIncreasingTime().
+ virtual void didReceiveLastInputEventForVSync(double frameTimeSeconds) { }
protected:
virtual ~WebInputHandlerClient() { }
« no previous file with comments | « no previous file | Source/WebKit/chromium/src/WebCompositorInputHandlerImpl.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698